@@ -1,6 +1,6 @@
 package DBIx::Custom;
 
-our $VERSION = '0.1687';
+our $VERSION = '0.1688';
 
 use 5.008001;
 use strict;
@@ -1009,6 +1009,19 @@ sub type_rule {
         my $type_rule = _array_to_hash([@_]);
         $self->{type_rule} = $type_rule;
         $self->{_into} ||= {};
+
+        foreach my $i (-1000 .. 1000) {
+             my $type_info = $self->dbh->type_info($i);
+             my $data_type = $type_info->{DATA_TYPE};
+             my $type_name = $type_info->{TYPE_NAME};
+             foreach my $type (keys %$type_rule) {
+                 use Data::Dumper;
+                 if ($type_name && lc $type eq lc $type_name) {
+                     $type_rule->{$data_type} = $type_rule->{$type};
+                 }
+             }
+        }
+
         $self->each_column(sub {
             my ($dbi, $table, $column, $column_info) = @_;
             
@@ -1556,7 +1569,7 @@ sub register_tag_processor {
 
 # DEPRECATED!
 sub update_param_tag {
-    warn "update_param is DEPRECATED! " .
+    warn "update_param_tag is DEPRECATED! " .
          "use update_param instead";
     return shift->update_param(@_);
 }
